@@ -190,7 +190,6 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
     r=GetSensorData()     
     if(r==1): #new data got added to array
         ProcessData(False)   
-        GenerateStatisticData()   
         ProcessAlarm()        
         
         WriteIntoRecordFile()
@@ -199,7 +198,9 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        data.GraphStart=max(GraphLen-779, 0)
         
         data.ScrollToEnd=True
-        GenerateGraphBitmap(RecordWindow)    
+        if(data.DisplayIsOn==True): 
+            GenerateStatisticData()   
+            GenerateGraphBitmap(RecordWindow)    
     
         if(records.Index==records.MaxArrayDataLen-1): 
             print "Stopped, array is full"
@@ -209,12 +210,12 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             StopMeasurement() #but keep alarm active!
     
     
-    if(data.DisplayIsOn==False):
-        if(data.debug==1): print "-> x Do not update screen, Display is off!"
-        pass
-    else:
+    if(data.DisplayIsOn==True):
         if(data.debug==1): print "-> o Update screen"
         RecordWindow.UpdateScreen()      
+    else:
+        if(data.debug==1): print "-> x Do not update screen, Display is off!"
+        
   
 #    print data.AlarmIsActive,  data.StopAfterAlarm
     if(data.AlarmIsActive==True):
@@ -456,7 +457,7 @@ class frmStartWindow(QMainWindow):
 
 
     ###########################################################################
-    # Show the collectring window (hera the data gets visualised during the logging)
+    ## Show the collectring window (her the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementNormal(self):
         if(data.debug==1): print "Measure in normal Mode"
@@ -468,7 +469,7 @@ class frmStartWindow(QMainWindow):
         
         
     ###########################################################################
-    # Show the collectring window (hera the data gets visualised during the logging)
+    ## Show the collectring window (her the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementQuick(self):
         if(data.debug==1): print "Measure in QuickMode"
@@ -477,8 +478,17 @@ class frmStartWindow(QMainWindow):
         self.StartMeasurement()
         
         
+        
+        
+        
+    ###########################################################################
+    ## 
+    ###########################################################################
     def StartMeasurement(self):
+        RecordWindow.ui.lblStatus.hide()
         RecordWindow.show()
+        app.processEvents() #force ui update  
+        
         InitRecord() #clear all old data
         InitMeasurement()
         RecordWindow.UpdateScreenStart()
@@ -489,10 +499,21 @@ class frmStartWindow(QMainWindow):
     ## Show the log window (where the data from a file gets visualised)
     ###########################################################################
     def ShowViewWindow(self):        
+        ViewWindow.ui.lblStart.setText("")
+        ViewWindow.ui.lblEnd.setText("")
+        ViewWindow.ui.lblNote.setText("")
+        ViewWindow.Canvas.hide()
+        ViewWindow.StatisticsCanvas.hide()
+        ViewWindow.show()
+        app.processEvents() #force ui update   
+        
         #reset to default log folder
         if(data.demo==True): data.logfolder=data.devlogfolder #folder on devel PC
         else: data.logfolder=data.defaultlogfolder
+
         LoadFileList()
+        data.arrLogFileIndex=len(data.arrLogFiles)-1 #no file selected, show latest
+        
         if os.path.exists(data.logfolder+data.lastlogfile):
             data.logfilename=data.lastlogfile
         else:
@@ -676,7 +697,7 @@ class frmRecordWindow(QMainWindow):
             self.ui.lblElapsedTime.setText("Elapsed time: "+d + " ("+str(records.Index)+" entries)")
         else: self.UpdateScreenStop()
         
-        self.ui.lblStatus.setText("Status: "+data.Status)
+        self.ui.lblStatus2.setText("Status: "+data.Status)
             
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -695,7 +716,7 @@ class frmRecordWindow(QMainWindow):
 
     def UpdateScreenStop(self):
         self.ui.bStop.setText("Close")
-        self.ui.lblStatus.setText("Status: "+data.Status)
+        self.ui.lblStatus2.setText("Status: "+data.Status)
         
         
         
@@ -708,34 +729,50 @@ class frmRecordWindow(QMainWindow):
 
 
     def ZoomIn(self):
+        self.ui.lblStatus.setText("Zoom in...")    
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update   
         Zoom(+1)
         GenerateGraphBitmap(self)
+        self.ui.lblStatus.hide()
         
 
 
     def ZoomOut(self):
+        self.ui.lblStatus.setText("Zoom out...")    
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update   
         Zoom(-1)
         GenerateGraphBitmap(self)
+        self.ui.lblStatus.hide()
 
 
 
     def RaiseTrigger(self):   
+        self.ui.lblStatus.setText("Raise trigger level...")    
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update   
         MoveTrigger(+1)
         self.ui.bLowerTrigger.setEnabled(True)
         if(data.Trigger==data.maxTrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
          
         GenerateGraphBitmap(self)
+        self.ui.lblStatus.hide()
         
         
         
     def LowerTrigger(self):     
+        self.ui.lblStatus.setText("Lower trigger level...")    
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update   
         MoveTrigger(-1)
         self.ui.bRaiseTrigger.setEnabled(True)
         if(data.Trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
          
         GenerateGraphBitmap(self)
+        self.ui.lblStatus.hide()
 
 
 
@@ -788,7 +825,7 @@ class frmRecordWindow(QMainWindow):
 ###########################################################################
 class frmViewWindow(QMainWindow):
     def __init__(self, parent=None):
-        global Canvas
+#        global Canvas
         QMainWindow.__init__(self, parent)
         if(data.demo==False): self.setAttribute(Qt.WA_Maemo5StackedWindow) # Also set the Stacked Window parameter for every subwindow in the stack
         
@@ -862,18 +899,18 @@ class frmViewWindow(QMainWindow):
 #        shortfolder=string.replace(data.logfolder, data.homedir, "~/")
 #        shortfolder=string.replace(shortfolder, "//", "/") #workaround
 #        self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
-        self.ui.lblLogfile.setText("Record: "+data.logfilename)
+#        self.ui.lblLogfile.setText("Record: "+data.logfilename)
 
 #        d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
         d0=strftime("%a. %x %X", records.StartTime_tuple)
 #        EndTime_tuple=Seconds2Tuple(Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000)
-        if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", records.EndTime_tuple)):
+#        if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", records.EndTime_tuple)):
 #            d1=strftime("%H:%M:%S", records.EndTime_tuple) #on same day, only show date once
 #        else:
 #            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) 
-            d1=strftime("%X", records.EndTime_tuple) #on same day, only show date once
-        else:
-            d1=strftime("%a. %x %X", records.EndTime_tuple) 
+#            d1=strftime("%X", records.EndTime_tuple) #on same day, only show date once
+#        else:
+        d1=strftime("%a. %x %X", records.EndTime_tuple) 
 #            
 #        diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
 #        diff_sec=Tuple2Seconds(records.EndTime_tuple)-Tuple2Seconds(records.StartTime_tuple)
@@ -886,7 +923,9 @@ class frmViewWindow(QMainWindow):
         diff=time.strftime("%H:%M:%S", time.gmtime(diff_sec))
         if(diff_sec>86400): d="1 day, " #longer than 24h
         else: d=""
-        self.ui.lblTimes.setText("Time: "+str(d0)+"  -  "+str(d1)+"  (Duration: "+d+str(diff)+")")
+#        self.ui.lblTimes.setText("Time: "+str(d0)+"  -  "+str(d1)+"  (Duration: "+d+str(diff)+")")
+        self.ui.lblStart.setText(str(d0))
+        self.ui.lblEnd.setText(str(d1)+" (Duration: "+d+str(diff)+")")
 
         self.ui.lblNote.setText("Note: "+records.Note)
 
@@ -923,6 +962,16 @@ class frmViewWindow(QMainWindow):
     ## 
     ###########################################################################
     def ShowLogFile(self):
+        
+        self.ui.lblStart.setText("")
+        self.ui.lblEnd.setText("")
+        self.ui.lblNote.setText("")
+        self.Canvas.hide()
+        self.StatisticsCanvas.hide()
+        self.ui.lblStatus.setText("Loading...")        
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update
+        
         r=LoadRecord()    
         if(r==1): #file too long            
             QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
@@ -935,8 +984,8 @@ class frmViewWindow(QMainWindow):
 #            QtGui.QMessageBox.warning(self, 'File header corrupted!', "The header data in the record file\n"+data.logfilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
 #        elif(r==4): #file is empty
 #            QtGui.QMessageBox.warning(self, 'File empty!', "The data in the record file\n"+data.logfilename+"\ncontains no data!", QtGui.QMessageBox.Ok)
-        elif(r==9): #Record too old
-            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
+#        elif(r==9): #Record too old
+#            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
 #        LoadFileList()
         ProcessData(True)
         GenerateStatisticData()
@@ -947,21 +996,17 @@ class frmViewWindow(QMainWindow):
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
 
 
+        self.ui.lblStatus.hide()
+        self.Canvas.show()
+        self.StatisticsCanvas.show()
         GenerateGraphBitmap(self)
         GenerateStatisticsBitmap(self)
         
-        self.update() #update statistic bars
       
         
         
-        
-        
 
         
-        
-        
-        
-        
     ###########################################################################
     ## 
     ###########################################################################
@@ -982,7 +1027,10 @@ class frmViewWindow(QMainWindow):
     ###########################################################################
     ## 
     ###########################################################################
-    def ZoomIn(self):
+    def ZoomIn(self):        
+        self.ui.lblStatus.setText("Zoom in...")    
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update        
         Zoom(+1)
         self.ui.bZoomOut.setEnabled(True)
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
@@ -993,10 +1041,10 @@ class frmViewWindow(QMainWindow):
 #        print "GraphStart:",  data.GraphStart
         
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
-        
-        
+                
         GenerateGraphBitmap(self)
         
+        self.ui.lblStatus.hide()
         
         
         
@@ -1009,6 +1057,9 @@ class frmViewWindow(QMainWindow):
     ## 
     ###########################################################################
     def ZoomOut(self):
+        self.ui.lblStatus.setText("Zoom out...")    
+        self.ui.lblStatus.show()
+        app.processEvents() #force ui update
         Zoom(-1)
         self.ui.bZoomIn.setEnabled(True)
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
@@ -1018,34 +1069,43 @@ class frmViewWindow(QMainWindow):
         
 #        data.ChangesInGraph=True #Make sure it only gets refreshed once
         
-        
         GenerateGraphBitmap(self)
+        
+        self.ui.lblStatus.hide()
 
         
     ###########################################################################
     ## 
     ###########################################################################
     def RaiseTrigger(self):   
+        self.ui.lblStatus.setText("Raise trigger level...")    
+        self.ui.lblStatus.show()
         MoveTrigger(+1)
+        app.processEvents() #force ui update
         
         GenerateGraphBitmap(self)
         
         GenerateStatisticData()
         GenerateStatisticsBitmap(self)
-        self.update() #update statistic bars
+#        self.update() #update statistic bars
+        self.ui.lblStatus.hide()
 
 
     ###########################################################################
     ## 
     ###########################################################################
-    def LowerTrigger(self):     
+    def LowerTrigger(self):    
+        self.ui.lblStatus.setText("Lower trigger level...")    
+        self.ui.lblStatus.show() 
         MoveTrigger(-1)
+        app.processEvents() #force ui update
         
         GenerateGraphBitmap(self)
         
         GenerateStatisticData()
         GenerateStatisticsBitmap(self)
-        self.update() #update statistic bars
+#        self.update() #update statistic bars
+        self.ui.lblStatus.hide()
     
         
 #    ###########################################################################
@@ -1087,15 +1147,19 @@ class frmViewWindow(QMainWindow):
     ## 
     ###########################################################################
     def DeleteLogFile(self):
+        self.ui.lblStatus.setText("Delete file...")        
+        self.ui.lblStatus.show()
         reply = QtGui.QMessageBox.question(self, 'Delete Record?', "Are you sure you want to delete this record:\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)    
-            
-            LoadFileList()
-            l=len(data.arrLogFiles)
-            if(l>0):
-                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
+
+            index=data.arrLogFileIndex
+            LoadFileList()            
+            if(len(data.arrLogFiles)>0):
+#                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
+                data.arrLogFileIndex=index-1
+                data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
             else: #no logfiles in logfolder, show "open file" dialog
                 tmp=self.ShowFileDialog()
                 if(tmp==""): #only continue if valid log file selected
@@ -1108,12 +1172,25 @@ class frmViewWindow(QMainWindow):
                 print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
             self.ShowLogFile()
             self.UpdateScreen()
+        self.ui.lblStatus.hide()
+        self.StatisticsCanvas.show()  
+            
 
 
     ###########################################################################
     ## 
     ###########################################################################
     def OpenRecord(self):
+         
+        self.ui.lblStart.setText("")
+        self.ui.lblEnd.setText("")
+        self.ui.lblNote.setText("")
+        self.Canvas.hide()
+        self.StatisticsCanvas.hide()
+        self.ui.lblStatus.setText("Opening file dialog...")        
+        self.ui.lblStatus.show()
+        
+        
         tmp=self.ShowFileDialog()
         if(not os.path.exists(tmp)): #only continue if valid log file selected
             return 
@@ -1124,6 +1201,8 @@ class frmViewWindow(QMainWindow):
         print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
         LoadFileList()
         self.ShowLogFile()
+        self.ui.lblStatus.hide()
+        self.StatisticsCanvas.show()  
     
     
     ###########################################################################
@@ -1182,6 +1261,9 @@ class frmViewWindow(QMainWindow):
         AdditionalInfoWindow.show()
 
 
+
+
+
     def Export(self):
         filename=string.replace(data.logfilename, ".csv",  "")
         tmp=QFileDialog.getSaveFileName(None,"Export graph as", data.defaultlogfolder+filename, "PNG-Image (*.png)") #;;JPEG-Image (*.jpg)
@@ -1357,15 +1439,21 @@ class frmDateWindow(QMainWindow):
 
 #        print "Load list of all csv files in folder:",  data.logfolder + " with date " + date
         output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *"+date+"*.csv").read() # run ls and make the output look like a file I can read
-        arrLogFiles=output.split("\n")
-        arrLogFiles.pop()
+        arr=output.split("\n")
 
-        amount=len(arrLogFiles)
+        amount=len(arr)-1
         
         self.ui.lblResult.setText("Found "+str(amount)+" Records for this date.")
         if(amount>0): 
             self.ui.bOpen.setEnabled(True)
-            data.LogFileSelectedDate=arrLogFiles[0] #select first file of that date for opening
+            data.LogFileSelectedDate=arr[0] #select first file of that date for opening
+            
+            for i in range(0,  len(data.arrLogFiles)-1):
+                if(data.arrLogFiles[i]==data.LogFileSelectedDate):
+#                    print "found:",  i
+                    data.arrLogFileIndex=i
+                    break
+            
         else: self.ui.bOpen.setEnabled(False)
 
 
@@ -1478,7 +1566,7 @@ class frmAdditionalInfoWindow(QMainWindow):
     ###########################################################################
     ## 
     ###########################################################################
-    def Close(self):
+    def Close(self):        
         self.close()
 
 
@@ -1732,6 +1820,9 @@ class DisplayStatusDaemon:
             if(data.run==True): 
                 if(data.debug==1): print "Update screen & graph"
 #                data.ChangesInGraph=True
+
+                GenerateStatisticData()   
+                GenerateGraphBitmap(RecordWindow)    
                 RecordWindow.Canvas.update()
                 RecordWindow.UpdateScreen()
 
@@ -1819,11 +1910,11 @@ class MyStatCanvas(QtGui.QWidget):
 ## 
 ###########################################################################        
 def GenerateGraphBitmap(self):    
-    if(data.DisplayIsOn==False):
-        if(data.debug==1): print "-> o Do not Generate Graph Bitmap, Display is off!"
-        return
-    else:
-        if(data.debug==1): print "-> x Generate Graph Bitmap"
+#    if(data.DisplayIsOn==False):
+#        if(data.debug==1): print "-> o Do not Generate Graph Bitmap, Display is off!"
+#        return
+#    else:
+    if(data.debug==1): print "Generate Graph Bitmap"
 
     Xscale=data.arrXscale[data.Xscale]
 #        data.GraphBitMapLen=max((records.LastIndex+5)/Xscale + 2 ,  770)
@@ -1835,7 +1926,7 @@ def GenerateGraphBitmap(self):
         data.GraphBitMap = QtGui.QPixmap(data.GraphBitMapLen, data.GraphBitMapHeight) #create bitmap for graph    
         DrawGraph(data.GraphBitMap,  QtGui) # draw graph
     except:
-        print "Error while creating the graph"
+        print "Error while creating the graph bitmap"
     
 #    ViewWindowCanvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
     self.Canvas.setGeometry(0, 0, data.GraphBitMapLen, data.GraphBitMapHeight)  #set size of canvas to graph 
@@ -1858,17 +1949,17 @@ def GenerateGraphBitmap(self):
 ## 
 ###########################################################################        
 def GenerateStatisticsBitmap(self):    
-    if(data.DisplayIsOn==False):
-        if(data.debug==1): print "-> o Do not Generate Statistics Bitmap, Display is off!"
-        return
-    else:
-        if(data.debug==1): print "-> x Generate Statistics Bitmap"
+#    if(data.DisplayIsOn==False):
+#        if(data.debug==1): print "-> o Do not Generate Statistics Bitmap, Display is off!"
+#        return
+#    else:
+    if(data.debug==1): print "Generate Statistics Bitmap"
 
     try:
         data.StatisticsBitMap = QtGui.QPixmap(data.StatisticsBitMapLen,  data.StatisticsBitMapHeight) #create bitmap for graph   
         DrawStatistic(data.StatisticsBitMap,  QtGui) #draw statistics
     except:
-        print "Error while creating the graph"
+        print "Error while creating the statistics bitmap"
     
     
 #    self.ui.CanvasWidget.hide()
